BraidConfig

Struct BraidConfig 

pub struct BraidConfig {
    pub mainbrain: MainbrainConfig,
    pub trigger: TriggerType,
    pub cameras: Vec<BraidCameraConfig>,
}
The Braid configuration format used in the Braid configuration TOML file.

This is the new configuration format. Backwards compatibility is maintained by first attempting to deserialize with this definition.

See the types of each field for sub-configuration values.

Fields

mainbrain: MainbrainConfig

Mainbrain configuration

trigger: TriggerType

Triggerbox configuration.

cameras: Vec<BraidCameraConfig>