MainbrainConfig

Struct MainbrainConfig 

pub struct MainbrainConfig {
    pub cal_fname: Option<PathBuf>,
    pub output_base_dirname: PathBuf,
    pub tracking_params: TrackingParams,
    pub lowlatency_camdata_udp_addr: Option<String>,
    pub lowlatency_camdata_udp_port: u16,
    pub http_api_server_addr: String,
    pub model_server_addr: SocketAddr,
    pub save_empty_data2d: bool,
    pub secret_base64: Option<String>,
    pub trusted_networks: Vec<String>,
    pub acquisition_duration_allowed_imprecision_msec: Option<f64>,
    pub write_buffer_size_num_messages: usize,
}
The sub-configuration of BraidConfig for mainbrain - the central component of Braid that integrates information from multiple cameras and performs tracking.

Fields

cal_fname: Option<PathBuf>

Filename of the camera calibration, optional.

Can contain shell variables such as ~, $A, or ${B}.

If the filename ends with .pymvg or .json, it will be treated as a pymvg calibration file. Else it will be treated considered in the flydra XML calibration format.

output_base_dirname: PathBuf

Directory where data should be saved. Can contain shell variables. Defaults to DEFAULT_OUTPUT_BASE_DIRNAME.

tracking_params: TrackingParams

Parameters for Kalman filter and data association

lowlatency_camdata_udp_addr: Option<String>

Address of UDP port to send low-latency detection data

lowlatency_camdata_udp_port: u16http_api_server_addr: String

Address of HTTP port for control API. This is specified in the format IP:PORT where:

IP can be:

  • a numerical IPv4 address:
    • e.g. 1.1.1.1 uses the specific IP
    • 127.0.0.1 for the loopback interface
    • 0.0.0.0 to open the server on all available IPv4 interfaces
  • a numerical IPv6 address:
    • e.g. [2001:db8:3333:4444:5555:6666:7777:8888] uses the specific IP
    • [::1] for the loopback interface
    • [::] to open the server on all available IPv6 interfaces
  • a hostname which resolves to an IP address (depending on your DNS configuration, resolves to either IPv4 or IPv6):
    • localhost resolves to the IP address of the loopback interface
    • e.g. hostname for a specific IP address

PORT can be:

  • 0 allows the operating system to choose an unassigned port dynamically
  • e.g. 1234 uses the specific port

Set to 0.0.0.0:0 to be automatically assigned a public IP address with a dynamically assigned port.

Both IPv4 and IPv6 addresses are accepted (see the format details above). Giving a non-localhost IP address makes Braid available remotely on the network. Remote clients must present an access token to connect. Using the unspecified IP address (0.0.0.0 for IPv4 or [::] for IPv6) exposes the server on all network interfaces. Using port 0 lets the operating system pick a free port.

The default value is set to DEFAULT_HTTP_API_SERVER_ADDR.

model_server_addr: SocketAddr

Address of HTTP port for model server emitting realtime tracking results

save_empty_data2d: bool

Save rows to data2d_distorted where nothing detected (saves timestamps)

secret_base64: Option<String>

Secret to use for signing HTTP cookies (base64 encoded)

trusted_networks: Vec<String>

Client networks (CIDR notation, e.g. 100.64.0.0/10 for Tailscale or a WireGuard subnet) that are trusted to have already authenticated the peer. Requests from these networks are accepted without an access token, delegating authentication to the overlay network. Defaults to empty.

acquisition_duration_allowed_imprecision_msec: Option<f64>

Threshold duration before logging error (msec).

If the image acquisition timestamp precedes the computed trigger timestamp, clearly an error has happened. This error must lie in the computation of the trigger timestamp. This specifies the threshold error at which an error is logged. (The underlying source of such errors remains unknown.)

write_buffer_size_num_messages: usize

The size of the buffer, in number of messages, used by the channel for sending data to disk.