pub struct BraidConfig {
pub mainbrain: MainbrainConfig,
pub trigger: TriggerType,
pub cameras: Vec<BraidCameraConfig>,
}Expand description
The Braid configuration format used in the Braid configuration TOML
file.
This is the new configuration format. Backwards compatibility is maintained by first attempting to deserialize with this definition.
See the types of each field for sub-configuration values.
Fields
mainbrain: MainbrainConfigMainbrain configuration
trigger: TriggerTypeTriggerbox configuration.
cameras: Vec<BraidCameraConfig>Trait Implementations
Sourceimpl Clone for BraidConfig
impl Clone for BraidConfig
Sourcefn clone(&self) -> BraidConfig
fn clone(&self) -> BraidConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BraidConfig
impl Debug for BraidConfig
Sourceimpl Default for BraidConfig
impl Default for BraidConfig
Sourceimpl<'de> Deserialize<'de> for BraidConfig
impl<'de> Deserialize<'de> for BraidConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more